@@ -4,6 +4,10 @@ from typing import List, Dict, Optional, Union, Any
 from ipfs_dict_chain.IPFSDictChain import IPFSDictChain
 from itertools import combinations
 import time
+import logging
+
+LOG = logging.getLogger(__name__)
+
 from .issue import HivemindIssue
 from .option import HivemindOption
 from .opinion import HivemindOpinion
